@@ -3,13 +3,15 @@ Main interface for mediatailor service client
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.mediatailor import MediaTailorClient
+    from mypy_boto3_mediatailor import MediaTailorClient
 
     session = boto3.Session()
 
     client: MediaTailorClient = boto3.client("mediatailor")
     session_client: MediaTailorClient = session.client("mediatailor")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 import sys
