@@ -3,14 +3,18 @@ Main interface for mediatailor service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.mediatailor import (
+
+    from mypy_boto3_mediatailor import MediaTailorClient
+    from mypy_boto3_mediatailor import (
         ListPlaybackConfigurationsPaginator,
     )
 
     client: MediaTailorClient = boto3.client("mediatailor")
 
     list_playback_configurations_paginator: ListPlaybackConfigurationsPaginator = client.get_paginator("list_playback_configurations")
+    ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from typing import Iterator, TYPE_CHECKING
